@@ -1,6 +1,3 @@
-# coding: utf8
-from __future__ import unicode_literals
-
 import pkg_resources
 import os
 
@@ -11,6 +8,13 @@ def get_file(filename):
     return pkg_resources.resource_filename(__name__, os.path.join("data", filename))
 
 
+mk = {
+    "lemma_lookup": get_file("mk_lemma_lookup.json"),
+    "lemma_rules": get_file("mk_lemma_rules.json"),
+    "lemma_index": get_file("mk_lemma_index.json"),
+    "lemma_exc": get_file("mk_lemma_exc.json"),
+    "lexeme_norm": get_file("mk_lexeme_norm.json"),
+}
 hr = {"lemma_lookup": get_file("hr_lemma_lookup.json")}
 pt = {
     "lemma_lookup": get_file("pt_lemma_lookup.json"),
@@ -24,8 +28,22 @@ da = {
     "lemma_lookup": get_file("da_lemma_lookup.json"),
     "lexeme_norm": get_file("da_lexeme_norm.json"),
 }
-ca = {"lemma_lookup": get_file("ca_lemma_lookup.json")}
-es = {"lemma_lookup": get_file("es_lemma_lookup.json")}
+ca = {
+    "lemma_lookup": get_file("ca_lemma_lookup.json"),
+    "lemma_exc": get_file("ca_lemma_exc.json"),
+    "lemma_index": get_file("ca_lemma_index.json"),
+    "lemma_rules": get_file("ca_lemma_rules.json"),
+}
+es = {
+    "lemma_lookup": get_file("es_lemma_lookup.json"),
+    "lemma_exc": get_file("es_lemma_exc.json"),
+    "lemma_index": get_file("es_lemma_index.json"),
+    "lemma_rules": get_file("es_lemma_rules.json"),
+    "lemma_rules_groups": get_file("es_lemma_rules_groups.json"),
+    "lexeme_cluster": get_file("es_lexeme_cluster.json"),
+    "lexeme_prob": get_file("es_lexeme_prob.json"),
+    "lexeme_settings": get_file("es_lexeme_settings.json"),
+}
 fr = {
     "lemma_rules": get_file("fr_lemma_rules.json"),
     "lemma_index": get_file("fr_lemma_index.json"),
@@ -41,8 +59,25 @@ tr = {"lemma_lookup": get_file("tr_lemma_lookup.json")}
 de = {
     "lemma_lookup": get_file("de_lemma_lookup.json"),
     "lexeme_norm": get_file("de_lexeme_norm.json"),
+    "lexeme_cluster": get_file("de_lexeme_cluster.json"),
+    "lexeme_prob": get_file("de_lexeme_prob.json"),
+    "lexeme_settings": get_file("de_lexeme_settings.json"),
+    "orth_variants": get_file("de_orth_variants.json"),
+}
+it = {
+    "lemma_lookup": get_file("it_lemma_lookup.json"),
+    "lemma_lookup_num": get_file("it_lemma_lookup_num.json"),
+    "lemma_lookup_det": get_file("it_lemma_lookup_det.json"),
+    "lemma_lookup_adp": get_file("it_lemma_lookup_adp.json"),
+    "lemma_lookup_adj": get_file("it_lemma_lookup_adj.json"),
+    "lemma_lookup_noun": get_file("it_lemma_lookup_noun.json"),
+    "lemma_lookup_pron": get_file("it_lemma_lookup_pron.json"),
+    "lemma_lookup_verb": get_file("it_lemma_lookup_verb.json"),
+    "lemma_lookup_aux": get_file("it_lemma_lookup_aux.json"),
+    "lemma_lookup_adv": get_file("it_lemma_lookup_adv.json"),
+    "lemma_lookup_other": get_file("it_lemma_lookup_other.json"),
+    "lemma_lookup_legacy": get_file("it_lemma_lookup_legacy.json"),
 }
-it = {"lemma_lookup": get_file("it_lemma_lookup.json")}
 lt = {"lemma_lookup": get_file("lt_lemma_lookup.json")}
 nl = {
     "lemma_rules": get_file("nl_lemma_rules.json"),
@@ -71,12 +106,18 @@ en = {
     "lemma_index": get_file("en_lemma_index.json"),
     "lemma_exc": get_file("en_lemma_exc.json"),
     "lexeme_norm": get_file("en_lexeme_norm.json"),
+    "lexeme_cluster": get_file("en_lexeme_cluster.json"),
+    "lexeme_prob": get_file("en_lexeme_prob.json"),
+    "lexeme_settings": get_file("en_lexeme_settings.json"),
+    "orth_variants": get_file("en_orth_variants.json"),
 }
 el = {
     "lemma_index": get_file("el_lemma_index.json"),
     "lemma_exc": get_file("el_lemma_exc.json"),
     "lemma_rules": get_file("el_lemma_rules.json"),
     "lexeme_norm": get_file("el_lexeme_norm.json"),
+    "lexeme_prob": get_file("el_lexeme_prob.json"),
+    "lexeme_settings": get_file("el_lexeme_settings.json"),
 }
 bn = {"lemma_rules": get_file("bn_lemma_rules.json")}
 tl = {"lemma_lookup": get_file("tl_lemma_lookup.json")}
@@ -85,7 +126,10 @@ lb = {
     "lemma_lookup": get_file("lb_lemma_lookup.json"),
     "lexeme_norm": get_file("lb_lexeme_norm.json"),
 }
-ru = {"lexeme_norm": get_file("ru_lexeme_norm.json")}
+ru = {
+    "lexeme_norm": get_file("ru_lexeme_norm.json"),
+    "lemma_lookup": get_file("ru_lemma_lookup.json"),
+}
 ta = {"lexeme_norm": get_file("ta_lexeme_norm.json")}
 th = {"lexeme_norm": get_file("th_lexeme_norm.json")}
 pl = {
@@ -99,22 +143,7 @@ pl = {
     "lemma_lookup_pron": get_file("pl_lemma_lookup_pron.json"),
     "lemma_lookup_verb": get_file("pl_lemma_lookup_verb.json"),
 }
-de_extra = {
-    "lexeme_cluster": get_file("de_lexeme_cluster.json"),
-    "lexeme_prob": get_file("de_lexeme_prob.json"),
-    "lexeme_settings": get_file("de_lexeme_settings.json"),
-}
-el_extra = {
-    "lexeme_prob": get_file("el_lexeme_prob.json"),
-    "lexeme_settings": get_file("el_lexeme_settings.json"),
-}
-en_extra = {
-    "lexeme_cluster": get_file("en_lexeme_cluster.json"),
-    "lexeme_prob": get_file("en_lexeme_prob.json"),
-    "lexeme_settings": get_file("en_lexeme_settings.json"),
-}
-es_extra = {
-    "lexeme_cluster": get_file("es_lexeme_cluster.json"),
-    "lexeme_prob": get_file("es_lexeme_prob.json"),
-    "lexeme_settings": get_file("es_lexeme_settings.json"),
+cs = {
+    "lemma_lookup": get_file("cs_lemma_lookup.json"),
+    "lexeme_norm": get_file("cs_lexeme_norm.json"),
 }
